@@ -60,8 +60,8 @@ def add_columns(lis__, db_name=''):
         if len(d_l) > 4 and d_l[3].upper() == 'FOREIGN':
             #for not null constraint
             const = f'{d_l[3]} {d_l[4]} {d_l[5]} {d_l[6]} {d_l[7]} {d_l[8]}'
-        else:
-            const = f'{d_l[3]}'
+        elif d_l[3] == 'UNIQUE':
+            const = d_l[3]
         constraint = const
         table_name = d_l[0]
         col_type = d_l[2]
@@ -70,10 +70,10 @@ def add_columns(lis__, db_name=''):
             create_tables(table_name, db_name)
             conn = sqlite3.connect(db_name)
             if constraint != 'UNIQUE':
-                conn.execute(f'ALTER TABLE {table_name} ADD COLUMN {col_name} {col_type} {constraint};')
+                conn.execute(f'ALTER TABLE {table_name} ADD COLUMN {col_name} {col_type} {constraint} ;')
             if constraint == 'UNIQUE':
                 conn.execute(f'ALTER TABLE {table_name} ADD COLUMN {col_name} {col_type};')
-                conn.execute(f'CREATE UNIQUE INDEX {col_name}_index ON {table_name}({col_name}) ;')
+                conn.execute(f'CREATE UNIQUE INDEX {table_name}_{col_name}_index ON {table_name}({col_name}) ;')
             conn.close()
 
 def get_tables(db_name):
